==> backup_download.php?file=website_backup_2025-05-04_05-55-00.zip: public/js/product-filter.js <==
document.addEventListener('DOMContentLoaded', function() {
    // 获取URL参数
    const urlParams = new URLSearchParams(window.location.search);
    // 当前筛选条件
    let currentFilters = {
        tag: urlParams.get('tag') ? parseInt(urlParams.get('tag')) : selectedTag || 0,
        region: urlParams.get('region') ? parseInt(urlParams.get('region')) : selectedRegion || 0,
        parent_region: urlParams.get('parent_region') ? parseInt(urlParams.get('parent_region')) : selectedParent || 0,
        min_price: urlParams.get('min_price') || selectedMinPrice || null,
        max_price: urlParams.get('max_price') || selectedMaxPrice || null,
        sort: urlParams.get('sort') || sortBy || 'recommended',
        order: urlParams.get('order') || sortOrder || '',
        page: urlParams.get('page') ? parseInt(urlParams.get('page')) : currentPage || 1
    };
    console.log('初始筛选条件:', currentFilters);
    // 初始化筛选结果统计
    updateFilterSummary();
    // 清除筛选按钮事件
    document.getElementById('clear-filters').addEventListener('click', function() {
        // 重置筛选条件
        currentFilters.tag = 0;
        currentFilters.region = 0;
        currentFilters.parent_region = 0;
        currentFilters.min_price = null;
        currentFilters.max_price = null;
        currentFilters.page = 1;
        // 移除所有筛选选项的active类
        document.querySelectorAll('.filter-option.active').forEach(opt => {
            opt.classList.remove('active');
        });
        // 隐藏筛选结果统计
        document.getElementById('filter-summary').style.display = 'none';
        // 重新加载产品列表
        loadFilteredProducts();
    });
    // 获取所有国家选项
    const countryOptions = document.querySelectorAll('.country-option');
    // 为每个国家选项添加点击事件
    countryOptions.forEach(option => {
        option.addEventListener('click', function() {
            // 移除所有国家选项的active类
            countryOptions.forEach(opt => opt.classList.remove('active'));
            // 为当前点击的选项添加active类
            this.classList.add('active');
            // 获取选中的父级地区ID
            const parentId = this.getAttribute('data-parent');
            // 设置当前筛选条件
            currentFilters.parent_region = parseInt(parentId);
            currentFilters.region = 0; // 清空具体地区筛选
            // 隐藏所有二级地区组
            const regionGroups = document.querySelectorAll('.region-group');
            regionGroups.forEach(group => {
                group.style.display = 'none';
                group.classList.remove('active');
            });
            // 显示对应的二级地区组
            const targetGroup = document.querySelector(`.region-group[data-parent="${parentId}"]`);
            // 判断该国家是否有二级地区，决定是否显示地区选择区块
            const regionFilterSection = document.getElementById('region-filter-section');
            if (targetGroup && targetGroup.querySelectorAll('.filter-option').length > 0) {
                // 有二级地区，显示区块
                regionFilterSection.style.display = '';
                targetGroup.style.display = 'flex';
                targetGroup.classList.add('active');
                // 清除所有地区选项的active类
                targetGroup.querySelectorAll('.filter-option').forEach(regionOpt => {
                    regionOpt.classList.remove('active');
                });
            } else {
                // 没有二级地区，隐藏区块
                regionFilterSection.style.display = 'none';
            }
            // 重置分页
            currentFilters.page = 1;
            // 加载筛选后的产品
            loadFilteredProducts();
        });
    });
    // 筛选选项点击事件
    document.querySelectorAll('.filter-option[data-filter]').forEach(option => {
        option.addEventListener('click', function() {
            const filterType = this.getAttribute('data-filter');
            // 找到当前筛选区块内的所有选项，并移除active类
            const filterSection = this.closest('.filter-section');
            if (filterSection) {
                filterSection.querySelectorAll(`.filter-option[data-filter="${filterType}"]`).forEach(opt => {
                    opt.classList.remove('active');
                });
            } else {
                // 如果没有找到父级区块，则移除所有相同类型的active类
                document.querySelectorAll(`.filter-option[data-filter="${filterType}"]`).forEach(opt => {
                    opt.classList.remove('active');
                });
            }
            this.classList.add('active');
            // 更新筛选条件
            if (filterType === 'region') {
                currentFilters.region = parseInt(this.getAttribute('data-value'));
                // 如果选择的是"全部"，则清空地区筛选
                if (currentFilters.region === 0) {
                    currentFilters.parent_region = 0;
                }
            } else if (filterType === 'parent_region') {
                currentFilters.parent_region = parseInt(this.getAttribute('data-value'));
                currentFilters.region = 0; // 清空具体地区筛选
            } else if (filterType === 'tag') {
                currentFilters.tag = parseInt(this.getAttribute('data-value'));
            } else if (filterType === 'price') {
                const minPrice = this.getAttribute('data-min');
                const maxPrice = this.getAttribute('data-max');
                currentFilters.min_price = minPrice ? minPrice : null;
                currentFilters.max_price = maxPrice ? maxPrice : null;
                // 显示筛选结果统计
                document.getElementById('filter-summary').style.display = 'flex';
            }
            // 重置分页
            currentFilters.page = 1;
            // 加载筛选后的产品
            loadFilteredProducts();
        });
    });
    // 排序选项点击事件
    document.querySelectorAll('.sort-option').forEach(option => {
        option.addEventListener('click', function() {
            const newSort = this.getAttribute('data-sort');
            // 移除所有排序选项的活跃状态
            document.querySelectorAll('.sort-option').forEach(opt => {
                opt.classList.remove('active');
            });
            // 为当前选项添加活跃状态
            this.classList.add('active');
            // 如果点击的是已经激活的排序选项，则切换排序方向
            if (currentFilters.sort === newSort) {
                // 设置排序方向
                if (newSort === 'price') {
                    currentFilters.order = currentFilters.order === 'desc' ? '' : 'desc';
                } else if (newSort === 'created') {
                    currentFilters.order = currentFilters.order === 'asc' ? '' : 'asc';
                }
            } else {
                // 新的排序选项，设置默认排序方向
                if (newSort === 'recommended' || newSort === 'sales') {
                    currentFilters.order = '';
                } else if (newSort === 'price') {
                    currentFilters.order = ''; // 默认ASC
                } else if (newSort === 'created') {
                    currentFilters.order = ''; // 默认DESC
                }
                currentFilters.sort = newSort;
            }
            // 更新图标
            if (newSort === 'price' || newSort === 'created') {
                const icon = this.querySelector('.material-icons');
                if (newSort === 'price') {
                    icon.textContent = currentFilters.order === 'desc' ? 'arrow_upward' : 'arrow_downward';
                } else if (newSort === 'created') {
                    icon.textContent = currentFilters.order === 'asc' ? 'arrow_upward' : 'arrow_downward';
                }
            }
            // 重置分页
            currentFilters.page = 1;
            // 加载筛选后的产品
            loadFilteredProducts();
        });
    });
    // 分页点击事件
    document.querySelectorAll('.page-item[data-page]').forEach(pageItem => {
        pageItem.addEventListener('click', function() {
            if (this.classList.contains('disabled')) return;
            const page = parseInt(this.getAttribute('data-page'));
            currentFilters.page = page;
            loadFilteredProducts();
        });
    });
    // 加载筛选后的产品
    function loadFilteredProducts() {
        // 打印当前筛选条件到控制台
        console.log('当前筛选条件:', currentFilters);
        const params = new URLSearchParams();
        if (currentFilters.tag) params.append('tag', currentFilters.tag);
        if (currentFilters.region) params.append('region', currentFilters.region);
        if (currentFilters.parent_region) params.append('parent_region', currentFilters.parent_region);
        if (currentFilters.min_price) params.append('min_price', currentFilters.min_price);
        if (currentFilters.max_price) params.append('max_price', currentFilters.max_price);
        if (currentFilters.sort) params.append('sort', currentFilters.sort);
        if (currentFilters.order) params.append('order', currentFilters.order);
        if (currentFilters.page) params.append('page', currentFilters.page);
        // 添加ajax参数，表示这是一个AJAX请求
        params.append('ajax', 1);
        // 更新筛选结果统计
        updateFilterSummary();
        // 构建URL - 使用当前页面路径而不是硬编码的product.html
        const url = `?${params.toString()}`;
        // 更新浏览器URL，但不刷新页面
        history.pushState(currentFilters, '', url);
        // 保存当前列表的高度，以防止闪烁
        const productList = document.querySelector('.product-list');
        const listHeight = productList.offsetHeight;
        productList.style.minHeight = `${listHeight}px`;
        // 添加遮罩层而不是全屏加载指示器
        const overlay = document.createElement('div');
        overlay.className = 'product-list-overlay';
        overlay.innerHTML = '<div class="spinner"></div>';
        overlay.style.cssText = `
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background: rgba(255, 255, 255, 0.6);
  display: flex;
  justify-content: center;
  align-items: center;
  z-index: 100;
  opacity: 0;
  transition: opacity 0.2s ease;
`;
        // 设置产品列表为相对定位，以便overlay能够正确定位
        if (getComputedStyle(productList).position === 'static') {
            productList.style.position = 'relative';
        }
        productList.appendChild(overlay);
        // 延迟显示加载指示器，避免短时间加载的闪烁
        let loadingTimeout = setTimeout(() => {
            overlay.style.opacity = '1';
        }, 200);
        // 创建AJAX请求 - 修改请求URL为code/product_ajax.php，使用基于当前位置的相对路径
        const ajaxUrl = `../code/product_ajax.php?${params.toString()}`;
        console.log('AJAX请求URL:', ajaxUrl);
        fetch(ajaxUrl)
            .then(response => response.json())
            .then(data => {
                // 清除超时
                clearTimeout(loadingTimeout);
                console.log('AJAX响应数据:', {
                    产品数量: data.totalItems,
                    当前页: data.currentPage,
                    总页数: data.totalPages
                });
                // 创建一个临时的容器来保存新内容
                const tempContainer = document.createElement('div');
                tempContainer.innerHTML = data.productList;
                // 创建分页临时容器
                const paginationContainer = document.createElement('div');
                paginationContainer.innerHTML = data.pagination;
                // 使用requestAnimationFrame确保DOM更新在下一帧执行，避免闪烁
                requestAnimationFrame(() => {
                    // 淡出当前内容
                    productList.style.opacity = '0';
                    document.querySelector('.pagination').style.opacity = '0';
                    // 在短暂延迟后更新内容并淡入
                    setTimeout(() => {
                        // 更新产品列表
                        productList.innerHTML = tempContainer.innerHTML;
                        // 更新分页
                        document.querySelector('.pagination').innerHTML = paginationContainer.innerHTML;
                        // 更新产品数量
                        const productCards = tempContainer.querySelectorAll('.product-card');
                        document.getElementById('product-count').textContent = productCards.length;
                        // 重新绑定分页事件
                        document.querySelectorAll('.page-item[data-page]').forEach(pageItem => {
                            pageItem.addEventListener('click', function() {
                                if (this.classList.contains('disabled')) return;
                                const page = parseInt(this.getAttribute('data-page'));
                                currentFilters.page = page;
                                loadFilteredProducts();
                            });
                        });
                        // 淡入新内容
                        productList.style.opacity = '1';
                        document.querySelector('.pagination').style.opacity = '1';
                        // 重置产品列表的最小高度
                        setTimeout(() => {
                            productList.style.minHeight = '';
                        }, 300);
                    }, 150);
                });
            })
            .catch(error => {
                console.error('AJAX错误:', error);
                // 清除超时
                clearTimeout(loadingTimeout);
                // 移除遮罩层
                if (productList.contains(overlay)) {
                    productList.removeChild(overlay);
                }
                // 如果出错，直接刷新页面
                window.location.href = url;
            });
    }
    // 更新筛选结果统计
    function updateFilterSummary() {
        const filterSummary = document.getElementById('filter-summary');
        // 检查是否有任何筛选条件被选中
        const hasFilters =
            currentFilters.tag > 0 ||
            currentFilters.region > 0 ||
            currentFilters.parent_region > 0 ||
            currentFilters.min_price !== null ||
            currentFilters.max_price !== null;
        // 如果有筛选条件，显示筛选结果统计
        if (hasFilters) {
            filterSummary.style.display = 'flex';
            // 更新产品数量（初始显示为当前页面上的产品数量）
            const productCards = document.querySelectorAll('.product-card');
            document.getElementById('product-count').textContent = productCards.length;
        } else {
            filterSummary.style.display = 'none';
        }
    }
    // 在页面加载完成后，初始化产品列表淡入效果的CSS
    const styleElement = document.createElement('style');
    styleElement.textContent = `
.product-list, .pagination {
  transition: opacity 0.3s ease;
}
`;
    document.head.appendChild(styleElement);
});

==> backup_download.php?file=website_backup_2025-05-06_06-33-27.zip: public/js/product-filter.js <==
document.addEventListener('DOMContentLoaded', function() {
    // 获取URL参数
    const urlParams = new URLSearchParams(window.location.search);
    // 当前筛选条件
    let currentFilters = {
        tag: urlParams.get('tag') ? parseInt(urlParams.get('tag')) : selectedTag || 0,
        region: urlParams.get('region') ? parseInt(urlParams.get('region')) : selectedRegion || 0,
        parent_region: urlParams.get('parent_region') ? parseInt(urlParams.get('parent_region')) : selectedParent || 0,
        min_price: urlParams.get('min_price') || selectedMinPrice || null,
        max_price: urlParams.get('max_price') || selectedMaxPrice || null,
        sort: urlParams.get('sort') || sortBy || 'price',
        order: urlParams.get('order') || sortOrder || 'asc',
        page: urlParams.get('page') ? parseInt(urlParams.get('page')) : currentPage || 1
    };
    console.log('初始筛选条件:', currentFilters);
    // 初始化筛选结果统计
    updateFilterSummary();
    // 清除筛选按钮事件
    document.getElementById('clear-filters').addEventListener('click', function() {
        // 重置筛选条件
        currentFilters.tag = 0;
        currentFilters.region = 0;
        currentFilters.parent_region = 0;
        currentFilters.min_price = null;
        currentFilters.max_price = null;
        currentFilters.page = 1;
        // 移除所有筛选选项的active类
        document.querySelectorAll('.filter-option.active').forEach(opt => {
            opt.classList.remove('active');
        });
        // 隐藏筛选结果统计
        document.getElementById('filter-summary').style.display = 'none';
        // 重新加载产品列表
        loadFilteredProducts();
    });
    // 获取所有国家选项
    const countryOptions = document.querySelectorAll('.country-option');
    // 为每个国家选项添加点击事件
    countryOptions.forEach(option => {
        option.addEventListener('click', function() {
            // 移除所有国家选项的active类
            countryOptions.forEach(opt => opt.classList.remove('active'));
            // 为当前点击的选项添加active类
            this.classList.add('active');
            // 获取选中的父级地区ID
            const parentId = this.getAttribute('data-parent');
            // 设置当前筛选条件
            currentFilters.parent_region = parseInt(parentId);
            currentFilters.region = 0; // 清空具体地区筛选
            // 隐藏所有二级地区组
            const regionGroups = document.querySelectorAll('.region-group');
            regionGroups.forEach(group => {
                group.style.display = 'none';
                group.classList.remove('active');
            });
            // 显示对应的二级地区组
            const targetGroup = document.querySelector(`.region-group[data-parent="${parentId}"]`);
            // 判断该国家是否有二级地区，决定是否显示地区选择区块
            const regionFilterSection = document.getElementById('region-filter-section');
            if (targetGroup && targetGroup.querySelectorAll('.filter-option').length > 0) {
                // 有二级地区，显示区块
                regionFilterSection.style.display = '';
                targetGroup.style.display = 'flex';
                targetGroup.classList.add('active');
                // 清除所有地区选项的active类
                targetGroup.querySelectorAll('.filter-option').forEach(regionOpt => {
                    regionOpt.classList.remove('active');
                });
            } else {
                // 没有二级地区，隐藏区块
                regionFilterSection.style.display = 'none';
            }
            // 重置分页
            currentFilters.page = 1;
            // 加载筛选后的产品
            loadFilteredProducts();
        });
    });
    // 筛选选项点击事件
    document.querySelectorAll('.filter-option[data-filter]').forEach(option => {
        option.addEventListener('click', function() {
            const filterType = this.getAttribute('data-filter');
            // 找到当前筛选区块内的所有选项，并移除active类
            const filterSection = this.closest('.filter-section');
            if (filterSection) {
                filterSection.querySelectorAll(`.filter-option[data-filter="${filterType}"]`).forEach(opt => {
                    opt.classList.remove('active');
                });
            } else {
                // 如果没有找到父级区块，则移除所有相同类型的active类
                document.querySelectorAll(`.filter-option[data-filter="${filterType}"]`).forEach(opt => {
                    opt.classList.remove('active');
                });
            }
            this.classList.add('active');
            // 更新筛选条件
            if (filterType === 'region') {
                currentFilters.region = parseInt(this.getAttribute('data-value'));
                // 如果选择的是"全部"，则清空地区筛选
                if (currentFilters.region === 0) {
                    currentFilters.parent_region = 0;
                }
            } else if (filterType === 'parent_region') {
                currentFilters.parent_region = parseInt(this.getAttribute('data-value'));
                currentFilters.region = 0; // 清空具体地区筛选
            } else if (filterType === 'tag') {
                currentFilters.tag = parseInt(this.getAttribute('data-value'));
            } else if (filterType === 'price') {
                const minPrice = this.getAttribute('data-min');
                const maxPrice = this.getAttribute('data-max');
                currentFilters.min_price = minPrice ? minPrice : null;
                currentFilters.max_price = maxPrice ? maxPrice : null;
                
                // 当选择价格范围时，自动设置排序为价格从低到高
                currentFilters.sort = 'price';
                currentFilters.order = 'asc';
                
                // 更新排序按钮的状态
                document.querySelectorAll('.sort-option').forEach(opt => {
                    opt.classList.remove('active');
                });
                const priceSort = document.querySelector('.sort-option[data-sort="price"]');
                if (priceSort) {
                    priceSort.classList.add('active');
                    const icon = priceSort.querySelector('.material-icons');
                    if (icon) {
                        icon.textContent = 'arrow_downward';
                    }
                }
                
                // 显示筛选结果统计
                document.getElementById('filter-summary').style.display = 'flex';
            }
            // 重置分页
            currentFilters.page = 1;
            // 加载筛选后的产品
            loadFilteredProducts();
        });
    });
    // 排序选项点击事件
    document.querySelectorAll('.sort-option').forEach(option => {
        option.addEventListener('click', function() {
            const newSort = this.getAttribute('data-sort');
            // 移除所有排序选项的活跃状态
            document.querySelectorAll('.sort-option').forEach(opt => {
                opt.classList.remove('active');
            });
            // 为当前选项添加活跃状态
            this.classList.add('active');
            // 如果点击的是已经激活的排序选项，则切换排序方向
            if (currentFilters.sort === newSort) {
                // 设置排序方向
                if (newSort === 'price') {
                    currentFilters.order = currentFilters.order === 'desc' ? 'asc' : 'desc';
                } else if (newSort === 'created') {
                    currentFilters.order = currentFilters.order === 'asc' ? 'desc' : 'asc';
                }
            } else {
                // 新的排序选项，设置默认排序方向
                if (newSort === 'recommended' || newSort === 'sales') {
                    currentFilters.order = '';
                } else if (newSort === 'price') {
                    currentFilters.order = 'asc';
                } else if (newSort === 'created') {
                    currentFilters.order = 'desc';
                }
                currentFilters.sort = newSort;
            }
            // 更新图标
            if (newSort === 'price' || newSort === 'created') {
                const icon = this.querySelector('.material-icons');
                if (newSort === 'price') {
                    icon.textContent = currentFilters.order === 'desc' ? 'arrow_upward' : 'arrow_downward';
                } else if (newSort === 'created') {
                    icon.textContent = currentFilters.order === 'asc' ? 'arrow_upward' : 'arrow_downward';
                }
            }
            // 重置分页
            currentFilters.page = 1;
            // 加载筛选后的产品
            loadFilteredProducts();
        });
    });
    // 分页点击事件
    document.querySelectorAll('.page-item[data-page]').forEach(pageItem => {
        pageItem.addEventListener('click', function() {
            if (this.classList.contains('disabled')) return;
            const page = parseInt(this.getAttribute('data-page'));
            currentFilters.page = page;
            loadFilteredProducts();
        });
    });
    // 加载筛选后的产品
    function loadFilteredProducts() {
        // 打印当前筛选条件到控制台
        console.log('当前筛选条件:', currentFilters);
        const params = new URLSearchParams();
        if (currentFilters.tag) params.append('tag', currentFilters.tag);
        if (currentFilters.region) params.append('region', currentFilters.region);
        if (currentFilters.parent_region) params.append('parent_region', currentFilters.parent_region);
        if (currentFilters.min_price) params.append('min_price', currentFilters.min_price);
        if (currentFilters.max_price) params.append('max_price', currentFilters.max_price);
        if (currentFilters.sort) params.append('sort', currentFilters.sort);
        if (currentFilters.order) params.append('order', currentFilters.order);
        if (currentFilters.page) params.append('page', currentFilters.page);
        // 添加ajax参数，表示这是一个AJAX请求
        params.append('ajax', 1);
        // 更新筛选结果统计
        updateFilterSummary();
        // 构建URL - 使用当前页面路径而不是硬编码的product.html
        const url = `?${params.toString()}`;
        // 更新浏览器URL，但不刷新页面
        history.pushState(currentFilters, '', url);
        // 保存当前列表的高度，以防止闪烁
        const productList = document.querySelector('.product-list');
        const listHeight = productList.offsetHeight;
        productList.style.minHeight = `${listHeight}px`;
        // 添加遮罩层而不是全屏加载指示器
        const overlay = document.createElement('div');
        overlay.className = 'product-list-overlay';
        overlay.innerHTML = '<div class="spinner"></div>';
        overlay.style.cssText = `
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background: rgba(255, 255, 255, 0.6);
  display: flex;
  justify-content: center;
  align-items: center;
  z-index: 100;
  opacity: 0;
  transition: opacity 0.2s ease;
`;
        // 设置产品列表为相对定位，以便overlay能够正确定位
        if (getComputedStyle(productList).position === 'static') {
            productList.style.position = 'relative';
        }
        productList.appendChild(overlay);
        // 延迟显示加载指示器，避免短时间加载的闪烁
        let loadingTimeout = setTimeout(() => {
            overlay.style.opacity = '1';
        }, 200);
        // 创建AJAX请求 - 修改请求URL为code/product_ajax.php，使用基于当前位置的相对路径
        const ajaxUrl = `../code/product_ajax.php?${params.toString()}`;
        console.log('AJAX请求URL:', ajaxUrl);
        fetch(ajaxUrl)
            .then(response => response.json())
            .then(data => {
                // 清除超时
                clearTimeout(loadingTimeout);
                console.log('AJAX响应数据:', {
                    产品数量: data.totalItems,
                    当前页: data.currentPage,
                    总页数: data.totalPages
                });
                // 创建一个临时的容器来保存新内容
                const tempContainer = document.createElement('div');
                tempContainer.innerHTML = data.productList;
                // 创建分页临时容器
                const paginationContainer = document.createElement('div');
                paginationContainer.innerHTML = data.pagination;
                // 使用requestAnimationFrame确保DOM更新在下一帧执行，避免闪烁
                requestAnimationFrame(() => {
                    // 淡出当前内容
                    productList.style.opacity = '0';
                    document.querySelector('.pagination').style.opacity = '0';
                    // 在短暂延迟后更新内容并淡入
                    setTimeout(() => {
                        // 更新产品列表
                        productList.innerHTML = tempContainer.innerHTML;
                        // 更新分页
                        document.querySelector('.pagination').innerHTML = paginationContainer.innerHTML;
                        // 更新产品数量
                        const productCards = tempContainer.querySelectorAll('.product-card');
                        document.getElementById('product-count').textContent = productCards.length;
                        // 重新绑定分页事件
                        document.querySelectorAll('.page-item[data-page]').forEach(pageItem => {
                            pageItem.addEventListener('click', function() {
                                if (this.classList.contains('disabled')) return;
                                const page = parseInt(this.getAttribute('data-page'));
                                currentFilters.page = page;
                                loadFilteredProducts();
                            });
                        });
                        // 淡入新内容
                        productList.style.opacity = '1';
                        document.querySelector('.pagination').style.opacity = '1';
                        // 重置产品列表的最小高度
                        setTimeout(() => {
                            productList.style.minHeight = '';
                        }, 300);
                    }, 150);
                });
            })
            .catch(error => {
                console.error('AJAX错误:', error);
                // 清除超时
                clearTimeout(loadingTimeout);
                // 移除遮罩层
                if (productList.contains(overlay)) {
                    productList.removeChild(overlay);
                }
                // 如果出错，直接刷新页面
                window.location.href = url;
            });
    }
    // 更新筛选结果统计
    function updateFilterSummary() {
        const filterSummary = document.getElementById('filter-summary');
        // 检查是否有任何筛选条件被选中
        const hasFilters =
            currentFilters.tag > 0 ||
            currentFilters.region > 0 ||
            currentFilters.parent_region > 0 ||
            currentFilters.min_price !== null ||
            currentFilters.max_price !== null;
        // 如果有筛选条件，显示筛选结果统计
        if (hasFilters) {
            filterSummary.style.display = 'flex';
            // 更新产品数量（初始显示为当前页面上的产品数量）
            const productCards = document.querySelectorAll('.product-card');
            document.getElementById('product-count').textContent = productCards.length;
        } else {
            filterSummary.style.display = 'none';
        }
    }
    // 在页面加载完成后，初始化产品列表淡入效果的CSS
    const styleElement = document.createElement('style');
    styleElement.textContent = `
.product-list, .pagination {
  transition: opacity 0.3s ease;
}
`;
    document.head.appendChild(styleElement);
});
